pub enum BaseOverrideError {
NotAUrl {
env: &'static str,
value: String,
},
}Expand description
Why the override environment could not become a client.
Variants
NotAUrl
A DOIGET_*_BASE is set but is not an absolute URL with a host.